@@ -54,6 +54,7 @@ def _resolve_filter_classes(cls_list):
             raise ImportError('Bad filter class: {}'.format(cdef))
 
         module = pynsive.import_module(cdef[:cdef.rfind('.')])
+        _LOG.debug('Searching for filter {} in module {}'.format(cdef, module))
 
         try:
             cls = getattr(module, cdef[cdef.rfind('.') + 1:])
@@ -66,7 +67,10 @@ def _resolve_filter_classes(cls_list):
             else:
                 raise TypeError(
                     'Type of a filter must be a function or a class')
-        except AttributeError:
+
+            _LOG.debug('Found definition for {} as {}'.format(cdef, cls))
+        except AttributeError as ae:
+            _LOG.exception(ae)
             raise ImportError('Unable to import: {}'.format(cdef))
     return filter_cls_list
 
@@ -162,9 +166,6 @@ def start_proxy(sockets, config):
     # Start tornado
     IOLoop.current().start()
 
-    # import cProfile
-    # cProfile.runctx('IOLoop.current().start()', globals(), locals())
-
 
 def start_pyrox(other_cfg=None):
     config = load_pyrox_config(other_cfg) if other_cfg else load_pyrox_config()
@@ -194,7 +195,21 @@ def start_pyrox(other_cfg=None):
     _LOG.info('Pyrox listening on: http://{0}:{1}'.format(
         bind_host[0], bind_host[1]))
 
-    # Start Tornado
+    # Are we trying to profile Pyrox?
+    if config.core.enable_profiling:
+        _LOG.warning("""
+**************************************************************************
+Notice: Pyrox Profiling Mode Enabled
+
+You have enabled Pyrox with profiling enabled in the Pyrox config. This
+will restrict Pyrox to one resident process. It is not recommended that
+you run Pyrox in production with this feature enabled.
+**************************************************************************
+""")
+        start_proxy(sockets, config)
+        return
+
+    # Number of processess to spin
     num_processes = config.core.processes
 
     if num_processes <= 0:
